@@ -228,7 +228,6 @@ class GtkUI(glchess.ui.UI):
         
         # Create the model for the player types
         self.__playerModel = gtk.ListStore(str, str, str)
-        iconTheme = gtk.icon_theme_get_default()
         iter = self.__playerModel.append()
         self.__playerModel.set(iter, 0, '', 1, 'stock_person', 2, _('Human'))
         
@@ -290,7 +289,7 @@ class GtkUI(glchess.ui.UI):
     
     def watchFileDescriptor(self, fd):
         """Extends ui.UI"""
-        self._watches[fd] = gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_HUP, self.__readData)
+        self._watches[fd] = gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR, self.__readData)
         
     def unwatchFileDescriptor(self, fd):
         """Extends ui.UI"""
@@ -322,7 +321,6 @@ class GtkUI(glchess.ui.UI):
         'name' is the name of the engine.
         TODO: difficulty etc etc
         """
-        iconTheme = gtk.icon_theme_get_default()
         iter = self.__playerModel.append()
         self.__playerModel.set(iter, 0, name, 1, 'stock_notebook', 2, name)
         
@@ -677,22 +675,6 @@ Please contact your system administrator to resolve these problems, until then y
         # Resize to fit text
         widget.set_size_request(int(width) + 6, -1)
 
-    def _on_show_toolbar_clicked(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            value = True
-        else:
-            value = False
-        glchess.config.set('show_toolbar', value)
-
-    def _on_show_history_clicked(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            value = True
-        else:
-            value = False
-        glchess.config.set('show_history', value)
-
     def _on_toggle_3d_clicked(self, widget):
         """Gtk+ callback"""
         if widget.get_active():
@@ -701,30 +683,6 @@ Please contact your system administrator to resolve these problems, until then y
             value = False
         glchess.config.set('show_3d', value)
 
-    def _on_menu_view_comment_clicked(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            value = True
-        else:
-            value = False
-        glchess.config.set('show_comments', value)
-
-    def _on_menu_view_numbering_clicked(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            value = True
-        else:
-            value = False
-        glchess.config.set('show_numbering', value)       
-
-    def _on_toggle_move_hints_clicked(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            value = True
-        else:
-            value = False
-        glchess.config.set('show_move_hints', value)       
-
     def _on_show_logs_clicked(self, widget):
         """Gtk+ callback"""
         window = self._gui.get_widget('log_window')
@@ -755,28 +713,6 @@ Please contact your system administrator to resolve these problems, until then y
 
         self.view._setMoveNumber(moveNumber)
 
-    def _on_menu_movef_human_activate(self, widget):
-        """Gtk+ callback"""
-        glchess.config.set('move_format', 'human')
-
-    def _on_menu_movef_lan_activate(self, widget):
-        """Gtk+ callback"""
-        glchess.config.set('move_format', 'lan')
-
-    def _on_menu_movef_san_activate(self, widget):
-        """Gtk+ callback"""
-        glchess.config.set('move_format', 'san')
-        
-    def _on_board_view_changed(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            glchess.config.set('board_view', self.__boardViewTypeByRadio[widget])
-
-    def _on_promotion_type_changed(self, widget):
-        """Gtk+ callback"""
-        if widget.get_active():
-            glchess.config.set('promotion_type', self.__promotionTypeByRadio[widget])
-        
     def __selectMoveNumber(self, moveNumber):
         """FIXME
         """
@@ -877,7 +813,16 @@ Please contact your system administrator to resolve these problems, until then y
 
     def _on_claim_draw_clicked(self, widget):
         """Gtk+ callback"""
-        self.view.feedback.claimDraw()
+        if not self.view.feedback.claimDraw():
+            dialog = gtk.MessageDialog(flags = gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                                       type = gtk.MESSAGE_WARNING,
+                                       message_format = _("Unable to claim draw"))
+        dialog.format_secondary_text(_("""You may claim a draw when:
+a) The board has been in the same state three times (Three fold repitition)
+b) Fifty moves have occured where no pawn has moved and no piece has been captured (50 move rule)"""))
+        dialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_ACCEPT)
+        dialog.run()
+        dialog.destroy()
 
     def _on_preferences_clicked(self, widget):
         """Gtk+ callback"""
